@@ -12,13 +12,13 @@ use Moo;
 
 has graph =>
 (
-	default  => sub{return {} },
+	default  => sub{return ''},
 	is       => 'rw',
 	#isa     => 'GraphViz2',
 	required => 0,
 );
 
-our $VERSION = '2.34';
+our $VERSION = '2.36';
 
 # -----------------------------------------------
 
@@ -287,7 +287,7 @@ Key-value pairs accepted in the parameter list:
 This option specifies the GraphViz2 object to use. This allows you to configure it as desired.
 
 The default is GraphViz2 -> new. The default attributes are the same as in the synopsis, above,
-except for the graph label of course.
+except for the logger of course, which defaults to ''.
 
 This key is optional.
 
@@ -321,7 +321,7 @@ Version numbers < 1.00 represent development versions. From 1.00 up, they are pr
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Support
 
